==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>選取一個或多個裝置</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>攝影機</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>切換至視窗</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>切換至全螢幕</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>倒數計時</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>選取一個或多個裝置</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>求助</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>錄影無法開始，磁碟空間不足</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>已到達磁碟空間上限</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>磁碟空間上限</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>錄影已經停止，磁碟空間不足</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>找不到檔案管理員程式</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>請安裝檔案管理員程式</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>桌面工作階段是 Wayland 工作階段</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>尚未支援 Wayland。螢幕將會空白一片。請登出並啟動 X11 桌面工作階段</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>來源程式碼</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>官方網頁</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>軟體介面翻譯</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐款支持</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>偵測到是 Wayland 桌面工作階段</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>開啟檔案</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>區域</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>繼續</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>結束</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>繼續</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>結束</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>對話匣</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>水平翻轉</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>垂直翻轉</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>色彩反轉</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>黑白</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>移除視窗外框</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>攝影機設定</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>區域</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>重設</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>縮放</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒數計時</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>視訊尺寸：</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>磁碟空間：</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>資訊</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>錄製時間：</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音訊</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>影格率</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>影像編碼</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音訊編碼</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>品質</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要錄製滑鼠游標</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>小時</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>分鐘</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>開始倒數</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>此時間後停止錄製：</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>小時</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>分鐘</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>影片路徑</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>磁碟空間上限</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>顯示在系統匣</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>開始錄製前等待秒數</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>檢查有否更新</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>求助</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>視訊</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>可提供</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>沒有</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>繼續</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>資料夾</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>攝影機</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>色彩反轉</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>發送報告</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>播放上一條影片</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>開始錄製時最小化</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>開啟時最小化</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>水平翻轉</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>垂直翻轉</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>黑白</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>移除視窗外框</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐款支持</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>下次開啟時，重設所有設定</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>圖片的版權及授權條款</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>螢幕播放</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>日誌</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>圖片的版權及授權條款</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>上一個影格</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>上一個影格</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>移動選單</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>選取一個或多個裝置</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>攝影機</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>切換至視窗</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>切換至全螢幕</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>選取一個或多個裝置</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>求助</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>找不到檔案管理員程式</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>請安裝檔案管理員程式</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>錄影無法開始，磁碟空間不足</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>已到達磁碟空間上限</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>磁碟空間上限</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>錄影已經停止，磁碟空間不足</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>找不到檔案管理員程式</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>請安裝檔案管理員程式</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>來源程式碼</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>官方網頁</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>軟體介面翻譯</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐款支持</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>選取一個或多個裝置</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>區域</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>繼續</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>結束</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>攝影機</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>縮放</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>繼續</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>結束</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>對話匣</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>水平翻轉</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>垂直翻轉</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>色彩反轉</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>黑白</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>移除視窗外框</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>攝影機設定</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>區域</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>重設</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>縮放</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒數計時</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>視訊尺寸：</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>磁碟空間：</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>資訊</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>錄製時間：</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音訊</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>影格率</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>影像編碼</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音訊編碼</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>品質</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要錄製滑鼠游標</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>小時</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>分鐘</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>開始倒數</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>此時間後停止錄製：</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>小時</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>分鐘</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>影片路徑</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>磁碟空間上限</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>顯示在系統匣</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>開始錄製前等待秒數</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>檢查有否更新</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>求助</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>視訊</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>可提供</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>沒有</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>繼續</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>資料夾</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>攝影機</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>色彩反轉</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>發送報告</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>播放上一條影片</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>開始錄製時最小化</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>開啟時最小化</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>水平翻轉</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>垂直翻轉</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>黑白</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>移除視窗外框</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐款支持</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>下次開啟時，重設所有設定</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>圖片的版權及授權條款</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>螢幕播放</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>日誌</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>圖片的版權及授權條款</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全螢幕</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>上一個影格</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>上一個影格</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>移動選單</translation>
    </message>
</context>
</TS>
